@@ -2,7 +2,7 @@ realm=__name__.split('.')[-2]
 input_type=__name__.split('.')[-1]
 
 from ... import pyteos_interface
-import sys
+import sys, imp
 
 desc={}
 desc['temperature']="absolute temperature (K).\n\n\
@@ -25,9 +25,17 @@ docstring="""
 This is for wet air with ice and liquid.
 """
 
+#Dynamically create function names!
+function_module = imp.new_module(realm+'_'+input_type)
+function_code="""
+def {0}(A,eta,p):
+    return pyteos_interface.attribute_to_function('{2}','{0}',A,eta,p)
+{0}.__name__='{0}'
+{0}.__doc__=\"\"\"{1}\"\"\"
+"""
+exec 'from pyteos_air import pyteos_interface' in function_module.__dict__
+
 for function_name in __all__:
-    def __tool(A,eta,p):
-        return pyteos_interface.attribute_to_function(realm+'_'+input_type,function_name,A,eta,p)
-    __tool.__name__=function_name
-    __tool.__doc__=docstring.format(desc[function_name])
-    setattr(sys.modules[__name__], function_name, __tool)
+    local_function_code=function_code.format(function_name,docstring.format(function_name),realm+'_'+input_type)
+    exec local_function_code in function_module.__dict__
+    setattr(sys.modules[__name__], function_name, getattr(function_module,function_name))
